@@ -26,16 +26,19 @@
 
 #include <gnome.h>
 
-gboolean  on_boot_table_clicked (GtkWidget*, gpointer);
+void      on_boot_table_default_toggled (GtkWidget*, gchar*, gpointer);
 void	  on_boot_table_cursor_changed	(GtkTreeSelection*, gpointer);
 void      on_boot_delete_clicked    (GtkButton *button, gpointer data);
 void      on_boot_settings_clicked  (GtkButton *button, gpointer data);
+void      on_boot_append_browse_clicked (GtkButton *button, gpointer data);
 void      on_boot_default_clicked   (GtkButton *button, gpointer data);
 void      on_main_dialog_update_complexity (GstDialog *main_dialog, gpointer data);
 
 void      callbacks_actions_set_sensitive      (gboolean state);
 gboolean  callbacks_conf_read_failed_hook (GstTool *tool, GstReportLine *rline, gpointer data);
 
+void on_use_password_clicked (GtkWidget *use_password, gpointer gdata);
+
 void on_popup_add_activate (gpointer, guint, GtkWidget*);
 void on_popup_settings_activate (gpointer, guint, GtkWidget*);
 void on_popup_delete_activate (gpointer, guint, GtkWidget*);
