@@ -69,6 +69,7 @@ GdkPixbuf *freebsd;
 GdkPixbuf *gentoo;
 GdkPixbuf *pld;
 GdkPixbuf *openna;
+GdkPixbuf *fedora;
 
 enum {
 	BOGUS,
@@ -452,6 +453,7 @@ gst_tool_create_distro_images (void)
 	gentoo = gdk_pixbuf_new_from_file (PIXMAPS_DIR "/gentoo.png", NULL);
 	pld = gdk_pixbuf_new_from_file (PIXMAPS_DIR "/pld.png", NULL);
 	openna = gdk_pixbuf_new_from_file (PIXMAPS_DIR "/openna.png", NULL);
+	fedora = gdk_pixbuf_new_from_file (PIXMAPS_DIR "/fedora.png", NULL);
 }
 
 static void
@@ -1353,8 +1355,8 @@ gst_tool_construct (GstTool *tool, const char *name, const char *title)
 	tool->directive_queue_idle_id = 0;
 
 	/* get the remote configuration gconf keys */
-	remote_config_key = g_strjoin ("/", GST_GCONF_ROOT, "global", "remote-configuration", NULL);
-	remote_hosts_key = g_strjoin ("/", GST_GCONF_ROOT, "global", "remote-hosts-list", NULL);
+	remote_config_key = g_strjoin ("/", GST_GCONF_ROOT, "global", "remote_configuration", NULL);
+	remote_hosts_key = g_strjoin ("/", GST_GCONF_ROOT, "global", "remote_hosts_list", NULL);
 
 	do_remote_conf = gconf_client_get_bool (client, remote_config_key, &error);
 	hosts = gconf_client_get_string (client, remote_hosts_key, &error);
@@ -1362,6 +1364,9 @@ gst_tool_construct (GstTool *tool, const char *name, const char *title)
 	tool->remote_config = ((do_remote_conf) && (hosts != NULL) && (strcmp (SSH_PATH, "") != 0));
 	if (hosts != NULL) 
 		tool->remote_hosts = g_strsplit (hosts, ",", -1);
+
+	g_free (remote_config_key);
+	g_free (remote_hosts_key);
 }
 
 GstTool *
@@ -1513,7 +1518,7 @@ try_show_usage_warning (void)
 
 	client = gconf_client_get_default ();
 
-	version_key = g_strjoin ("/", GST_GCONF_ROOT, "global", "last-version", NULL);
+	version_key = g_strjoin ("/", GST_GCONF_ROOT, "global", "last_version", NULL);
 	key = g_strjoin ("/", GST_GCONF_ROOT, "global", "show_warning", NULL);
 
 
@@ -1675,15 +1680,20 @@ gst_tool_write_to_backend (GstTool *tool, gchar *string)
 {
 	gint ntotal = 0;
 	gint nread = 0;
-	gint ret;
+	int ret;
 	gchar *p;
 
+	/* turn the descriptor blocking for writing the configuration */
+	fcntl (tool->backend_master_fd, F_SETFL, 0);
+
 	do {
 		ret = fputc (string [nread], tool->backend_stream);
 
-		if (ret >= 0)
+		if (ret != EOF)
 			nread++;
 	} while (nread < strlen (string));
 
+	fcntl (tool->backend_master_fd, F_SETFL, O_NONBLOCK);
+	
 	while (fflush (tool->backend_stream) != 0);
 }
