@@ -26,15 +26,16 @@
 #  include <config.h>
 #endif
 
-#include <gnome.h>
+#include <gtk/gtk.h>
 
 #include "gst.h"
 #include "table.h"
 #include "callbacks.h"
 
-extern GstTool *tool;
+#define RESPONSE_START_SERVICE 1
+#define RESPONSE_STOP_SERVICE 2
 
-GList *parameters_list = NULL;
+extern GstTool *tool;
 
 /* Helpers */
 static gchar*
@@ -47,33 +48,6 @@ service_get_description (xmlNodePtr service)
 	return description;
 }
 
-static void
-service_get_parameters (gchar *script)
-{
-	xmlNodePtr root, node;
-	xmlDocPtr parameters = gst_tool_run_get_directive (tool, NULL, "service_parameters", script, NULL);
-	gchar *param;
-	GtkWidget *option_menu = gst_dialog_get_widget (tool->main_dialog, "dialog_service_parameters");
-	GtkWidget *menu = gtk_menu_new ();
-	GtkWidget *menu_item;
-
-	root = gst_xml_doc_get_root (parameters);
-
-	for (node = gst_xml_element_find_first (root, "parameter");
-	     node != NULL;
-	     node = gst_xml_element_find_next (node, "parameter"))
-	{
-		param = gst_xml_element_get_content (node);
-		menu_item = gtk_menu_item_new_with_label (param);
-		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
-		gtk_widget_show (menu_item);
-
-		parameters_list = g_list_append (parameters_list, param);
-	}
-
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), menu);
-}
-
 static gint
 get_current_runlevel (GstTool *tool)
 {
@@ -170,14 +144,22 @@ toggle_service (GstTool *tool, xmlNodePtr service, gint runlevel, gboolean statu
 
 }
 
+void
+change_runlevel (gint runlevel)
+{
+	xmlNodePtr root = gst_xml_doc_get_root (tool->config);
+
+	table_clear ();
+	table_populate (root, runlevel);
+}
 
 /* callbacks */
 static void
-callbacks_set_buttons_sensitive ()
+callbacks_set_buttons_sensitive (gboolean enabled)
 {
 	GtkWidget *settings_button = gst_dialog_get_widget (tool->main_dialog, "settings_button");
 
-	gtk_widget_set_sensitive (settings_button, TRUE);
+	gtk_widget_set_sensitive (settings_button, enabled);
 }
 
 static void
@@ -191,42 +173,25 @@ callbacks_description_changed (xmlNodePtr service)
 }
 
 void
-on_runlevel_table_clicked (GtkTreeView *treeview, gpointer data)
+on_services_table_select_row (GtkTreeSelection *selection, gpointer data)
 {
 	GtkTreeModel *model;
 	GtkTreePath *path;
 	GtkTreeIter iter;
-	GtkTreeViewColumn *column;
 	xmlNodePtr service;
 
-	g_return_if_fail (GTK_IS_TREE_VIEW (treeview));
+	if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
+		callbacks_set_buttons_sensitive (TRUE);
 
-	gtk_tree_view_get_cursor (GTK_TREE_VIEW (treeview), &path, &column);
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW (treeview));
-	gtk_tree_model_get_iter (model, &iter, path);
-	
-	/* get the xmlNodePtr */
-	gtk_tree_model_get (model, &iter, COL_POINTER, &service, -1);
+		/* get the xmlNodePtr */
+		gtk_tree_model_get (model, &iter, COL_POINTER, &service, -1);
 
-	/* Change the description label */
-	callbacks_description_changed (service);
+		/* Change the description label */
+		callbacks_description_changed (service);
 
-	/* we also want to show the service description in the window */
-	callbacks_set_buttons_sensitive (); 
-
-	/* free the variables */
-	gtk_tree_path_free (path);
-}
-
-void
-on_throw_service_button_clicked (GtkWidget *button, gpointer data)
-{
-	GtkWidget *script_label = gst_dialog_get_widget (tool->main_dialog, "dialog_script_name");
-	GtkWidget *option_menu = gst_dialog_get_widget (tool->main_dialog, "dialog_service_parameters");
-	gchar *script = (gchar *) gtk_label_get_text (GTK_LABEL (script_label));
-	gchar *parameter = g_list_nth_data (parameters_list, gtk_option_menu_get_history (GTK_OPTION_MENU (option_menu)));
-
-	gst_tool_run_get_directive (tool, NULL, "throw_service", script, parameter, NULL);
+	} else {
+		callbacks_set_buttons_sensitive (FALSE);
+	}
 }
 
 void
@@ -249,6 +214,7 @@ on_service_priority_changed (GtkWidget *spin_button, gpointer data)
 
 	/* if the new value is equal to the old value, don't do nothing */
 	old_value = gst_xml_get_child_content (service, "priority");
+
 	if (strcmp (old_value, value) == 0)
 		return;
 
@@ -259,6 +225,42 @@ on_service_priority_changed (GtkWidget *spin_button, gpointer data)
 	g_free (value);
 }
 
+static void
+dialog_service_get_status (gchar *script)
+{
+	xmlNodePtr root, node;
+	xmlDocPtr doc;
+	GtkWidget *status_label = gst_dialog_get_widget (tool->main_dialog, "dialog_status_label");
+	GtkWidget *start_button = gst_dialog_get_widget (tool->main_dialog, "dialog_start_button");
+	GtkWidget *stop_button = gst_dialog_get_widget (tool->main_dialog, "dialog_stop_button");
+
+	doc = gst_tool_run_get_directive (tool, NULL, "get_status", script, NULL);
+
+	if (!doc)
+		return;
+
+	root = gst_xml_doc_get_root (doc);
+	node = gst_xml_element_find_first (root, "active");
+
+	if (node) {
+		if (gst_xml_element_get_bool_attr (node, "state")) {
+			gtk_label_set_text (GTK_LABEL (status_label), _("Running"));
+			gtk_widget_set_sensitive (start_button, FALSE);
+			gtk_widget_set_sensitive (stop_button, TRUE);
+		} else {
+			gtk_label_set_text (GTK_LABEL (status_label), _("Stopped"));
+			gtk_widget_set_sensitive (start_button, TRUE);
+			gtk_widget_set_sensitive (stop_button, FALSE);
+		}
+	} else {
+		gtk_label_set_text (GTK_LABEL (status_label), _("Could not get info"));
+		gtk_widget_set_sensitive (start_button, TRUE);
+		gtk_widget_set_sensitive (stop_button, TRUE);
+	}
+
+	gst_xml_doc_destroy (doc);
+}
+
 void
 on_settings_button_clicked (GtkWidget *button, gpointer data)
 {
@@ -266,20 +268,22 @@ on_settings_button_clicked (GtkWidget *button, gpointer data)
 	GtkWidget *script_name = gst_dialog_get_widget (tool->main_dialog, "dialog_script_name");
 	GtkWidget *service_description = gst_dialog_get_widget (tool->main_dialog, "dialog_service_description");
 	GtkWidget *service_priority = gst_dialog_get_widget (tool->main_dialog, "dialog_service_priority");
-	GtkWidget *option_menu = gst_dialog_get_widget (tool->main_dialog, "dialog_service_parameters");
+	GtkWidget *service_priority_label = gst_dialog_get_widget (tool->main_dialog, "dialog_service_priority_label");
 
 	/* we need these to get the xmlNodePtr */
 	GtkTreeView *runlevel_table = GTK_TREE_VIEW (gst_dialog_get_widget (tool->main_dialog, "runlevel_table"));
 	GtkTreeModel *model = gtk_tree_view_get_model (runlevel_table);
-	GtkTreePath *path;
 	GtkTreeIter iter;
+	GtkTreeSelection *selection;
 	xmlNodePtr service;
 	
-	gchar *description, *script, *title;
-	gint priority;
+	gchar *description, *script, *title, *p;
+	gint priority, response;
 
-	gtk_tree_view_get_cursor (runlevel_table, &path, NULL);
-	gtk_tree_model_get_iter (model, &iter, path);
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (runlevel_table));
+
+	if (!gtk_tree_selection_get_selected (selection, &model, &iter))
+		return;
 
 	/* get the xmlNodePtr */
 	gtk_tree_model_get (model, &iter, COL_POINTER, &service, -1);
@@ -288,41 +292,59 @@ on_settings_button_clicked (GtkWidget *button, gpointer data)
 	script = gst_xml_get_child_content (service, "script");
 	description = service_get_description (service);
 
-	/* get the priority */
-	priority = atoi (gst_xml_get_child_content (service, "priority"));
-	
+	/* get the priority, if it doesn't exist, we simply hide the spinbutton */
+	p = gst_xml_get_child_content (service, "priority");
+
+	if (p == NULL) {
+		gtk_widget_hide (service_priority);
+		gtk_widget_hide (service_priority_label);
+	} else {
+		gtk_widget_show (service_priority);
+		gtk_widget_show (service_priority_label);
+		
+		priority = atoi (p);
+
+		/* we're modifying the spin button, so we need to block its signal handlers */
+		g_signal_handlers_block_by_func (G_OBJECT (service_priority),
+						 G_CALLBACK (on_service_priority_changed), tool->main_dialog);
+
+		gtk_spin_button_set_value (GTK_SPIN_BUTTON (service_priority), priority);
+
+		g_signal_handlers_unblock_by_func (G_OBJECT (service_priority),
+						   G_CALLBACK (on_service_priority_changed), tool->main_dialog);
+
+		g_free (p);
+	}
+
 	gtk_label_set_text (GTK_LABEL (script_name), script);
 	gtk_label_set_text (GTK_LABEL (service_description), description);
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (service_priority), priority);
-
-	/* sets the option menu with the valid service parameters */
-	service_get_parameters (script);
 
 	title = g_strdup_printf (_("Settings for service %s"), script);
 	gtk_window_set_title (GTK_WINDOW (dialog), title);
 
-	gtk_dialog_run (GTK_DIALOG (dialog));
+	dialog_service_get_status (script);
+
+	response = gtk_dialog_run (GTK_DIALOG (dialog));
+
+	if (response == RESPONSE_STOP_SERVICE)
+		gst_tool_run_get_directive (tool, NULL, "throw_service", script, "stop", NULL);
+	else if (response == RESPONSE_START_SERVICE)
+		gst_tool_run_get_directive (tool, NULL, "throw_service", script, "start", NULL);
+		
 	gtk_widget_hide (dialog);
 
 	/* we don't need this menu anymore */
-	gtk_option_menu_remove_menu (GTK_OPTION_MENU (option_menu));
 	g_free (description);
 	g_free (script);
 	g_free (title);
-
-	/* we need to free the list and put it again to NULL, it may be used again */
-	g_list_free (parameters_list);
-	parameters_list = NULL;
 }
 
 void
 on_runlevel_changed (GtkWidget *widget, gpointer data)
 {
 	gint runlevel = GPOINTER_TO_INT (data);
-	xmlNodePtr root = gst_xml_doc_get_root (tool->config);
 
-	table_clear ();
-	table_populate (root, runlevel);
+	change_runlevel (runlevel);
 }
 
 void
@@ -348,7 +370,6 @@ on_service_toggled (GtkWidget *widget, gchar *path_str, gpointer data)
 	/* change the XML */
 	toggle_service (tool, service, runlevel, new_value);
 	
-
 	gtk_tree_store_set (GTK_TREE_STORE (model),
 			    &iter,
 			    COL_ACTIVE, new_value,
@@ -358,3 +379,39 @@ on_service_toggled (GtkWidget *widget, gchar *path_str, gpointer data)
 
 	gtk_tree_path_free (path);
 }
+
+void
+on_popup_settings_activate (gpointer callback_data, guint action, GtkWidget *widget)
+{
+	on_settings_button_clicked (widget, callback_data);
+}
+
+gboolean
+on_table_button_press_event (GtkWidget *widget, GdkEventButton *event, gpointer data)
+{
+	GtkTreePath *path;
+	GtkItemFactory *item_factory;
+	GtkTreeView *treeview = GTK_TREE_VIEW (widget);
+
+	item_factory = (GtkItemFactory *) data;
+
+	if (gst_dialog_get_complexity (tool->main_dialog) == GST_DIALOG_BASIC)
+		return;
+
+	if (event->button == 3) {
+		gtk_widget_grab_focus (widget);
+
+		if (gtk_tree_view_get_path_at_pos (treeview, event->x, event->y, &path, NULL, NULL, NULL))
+		{
+			gtk_tree_selection_unselect_all (gtk_tree_view_get_selection (treeview));
+			gtk_tree_selection_select_path (gtk_tree_view_get_selection (treeview), path);
+
+			gtk_item_factory_popup (item_factory, event->x_root, event->y_root,
+						event->button, event->time);
+		}
+
+		return TRUE;
+	}
+
+	return FALSE;
+}
