@@ -35,12 +35,14 @@ transfer_populate_option_menu (GstTool *tool, xmlNodePtr root)
 {
 	xmlNodePtr runlevels = gst_xml_element_find_first (root, "runlevels");
 	xmlNodePtr runlevel;
-	GtkWidget *menu_item, *menu_shell, *option_menu;
-	gint i, n_item, n_option;
-
-	n_item = 0;
-	option_menu = gst_dialog_get_widget (tool->main_dialog, "runlevels_menu");
-	gtk_option_menu_remove_menu (GTK_OPTION_MENU (option_menu));
+	GtkWidget *menu_item, *menu_shell;
+	GstWidget *option_menu;
+	gint i, n_option, first_runlevel;
+	gboolean has_default = FALSE;
+	gint n_items = 0;
+	
+	option_menu = gst_dialog_get_gst_widget (tool->main_dialog, "runlevels_menu");
+	gtk_option_menu_remove_menu (GTK_OPTION_MENU (option_menu->widget));
 	
 	menu_shell = gtk_menu_new ();
 
@@ -49,6 +51,11 @@ transfer_populate_option_menu (GstTool *tool, xmlNodePtr root)
 	     runlevel = gst_xml_element_find_next (runlevel, "runlevel"))
 	{
 		i = atoi (gst_xml_get_child_content (runlevel, "number"));
+
+		/* we save the first runlevel, just if there is no default runlevel */
+		if (n_items == 0)
+			first_runlevel = i;
+		
 		menu_item = gtk_menu_item_new_with_label (gst_xml_get_child_content (runlevel,
 										     "description"));
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu_shell), menu_item);
@@ -60,17 +67,30 @@ transfer_populate_option_menu (GstTool *tool, xmlNodePtr root)
 
 		if (gst_xml_get_child_content (runlevel, "default") != NULL) {
 			/* It's the default runlevel */
-			n_option = n_item;
-			g_signal_emit_by_name (G_OBJECT (menu_item), "activate", GINT_TO_POINTER (i));
+			has_default = TRUE;
+			n_option = n_items;
 			g_object_set_data (G_OBJECT (menu_item), "default", GINT_TO_POINTER (TRUE));
+			change_runlevel (i);
 		}
 
-		n_item++;
+		n_items++;
+	}
+
+	if (n_items == 1) {
+		/* it's has only one runlevel, we should hide the runlevels list at all */
+		option_menu->advanced = GST_WIDGET_MODE_HIDDEN;
+		gst_widget_apply_policy (option_menu);
+	} else {
+		gtk_widget_show_all (menu_shell);
+		gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu->widget), menu_shell);
+		gtk_option_menu_set_history (GTK_OPTION_MENU (option_menu->widget), n_option);
+	}
+
+	if (!has_default) {
+		/* there isn't a default, so we load the first runlevel in the list */
+		gtk_option_menu_set_history (GTK_OPTION_MENU (option_menu->widget), 0);
+		change_runlevel (first_runlevel);
 	}
-	
-	gtk_widget_show_all (menu_shell);
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), menu_shell);
-	gtk_option_menu_set_history (GTK_OPTION_MENU (option_menu), n_option);
 }
 
 void
